fetchMessages abstract method
Fetches all existing messages for the conversation at path, ordered
oldest first.
Implementation
Future<List<ChatBackendMessage>> fetchMessages(String path);
Fetches all existing messages for the conversation at path, ordered
oldest first.
Future<List<ChatBackendMessage>> fetchMessages(String path);