backend property
The backend used to load, send, and stream this chat's messages, e.g.
FirestoreChatBackend(), AppwriteChatBackend(...), or
SupabaseChatBackend(...).
Implementation
final ChatBackend backend;
The backend used to load, send, and stream this chat's messages, e.g.
FirestoreChatBackend(), AppwriteChatBackend(...), or
SupabaseChatBackend(...).
final ChatBackend backend;