onMessageSent property
Called with the sent message text and this ChatEntity whenever a message is successfully sent, e.g. to trigger a push notification.
Implementation
final Function(String message, ChatEntity chatEntity) onMessageSent;
Called with the sent message text and this ChatEntity whenever a message is successfully sent, e.g. to trigger a push notification.
final Function(String message, ChatEntity chatEntity) onMessageSent;