subscribeToNewMessages abstract method
Subscribes to newly created messages for the conversation at path.
The returned stream emits one ChatBackendMessage per new message. Implementations must not emit messages already returned by fetchMessages.
Implementation
Stream<ChatBackendMessage> subscribeToNewMessages(String path);