PeerUser class
A lightweight representation of a chat participant.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
The unique id of the user.
latefinal
- image ↔ String?
-
The profile image URL of the user, if any.
latefinal
- name ↔ String
-
The display name of the user.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toChatUser(
) → ChatUser -
Converts this PeerUser into a
dash_chat_customChatUser. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited