InappChat class
Entry point for opening the chat UI backed by a ChatEntity's
ChatBackend.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chatPageWidget(
ChatEntity chatEntity) → MaterialPageRoute -
Builds a MaterialPageRoute for the chat page for
chatEntity, for use with custom navigation (e.g. named routes). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openChatPage(
BuildContext context, ChatEntity chatEntity) → Future< Future> -
Pushes the chat page for
chatEntityonto the navigator. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited